@@ -549,7 +549,7 @@ PPOActionCriticReturn = namedtuple('PPOActionCriticReturn', [
 ])
 
 @beartype
-class ActorWithValueHead(nn.Module):
+class ActorCritic(nn.Module):
     def __init__(
         self,
         palm: PaLM,
@@ -573,10 +573,7 @@ class ActorWithValueHead(nn.Module):
         self.critic_lora_scope = critic_lora_scope
 
         self.pooled_values = pooled_values
-        self.value_head = nn.Sequential(
-            nn.Linear(palm.dim, 1),
-            Rearrange('... 1 -> ...')
-        )
+        self.value_head = nn.Linear(palm.dim, 1)
 
     def actor_parameters(self):
         return [
@@ -625,7 +622,7 @@ class ActorWithValueHead(nn.Module):
 
         action_logits = rearrange(action_logits, '1 ... -> ...')
 
-        value = rearrange(value, '1 ->')
+        value = rearrange(value, '... 1 -> ...')
 
         return PPOActionCriticReturn(
             actions,
@@ -641,13 +638,10 @@ class ActorWithValueHead(nn.Module):
         x,
         mask = None
     ):
-        actor_embeds = self.actor_palm(
+        action_logits = self.actor_palm(
             x,
-            return_only_embedding = True,
             finetune_scope = self.actor_lora_scope
-        )        
-
-        action_logits = self.actor_palm.to_logits(actor_embeds)
+        )
 
         critic_embeds = self.critic_palm(
             x,
